@@ -15,18 +15,23 @@
 $Id: __init__.py 97 2007-03-29 22:58:27Z rineichen $
 """
 
+import re
 import unittest
+from zope.testing import renormalizing
 from zope.app.testing import functional
 
 functional.defineLayer('TestLayer', 'ftesting.zcml')
 
+checker = renormalizing.RENormalizing([
+    (re.compile(r'httperror_seek_wrapper:', re.M), 'HTTPError:'),
+    ])
+
 
 def test_suite():
     suite = unittest.TestSuite()
-    s = functional.FunctionalDocFileSuite('../README.txt')
+    s = functional.FunctionalDocFileSuite('../README.txt', checker=checker)
     s.layer = TestLayer
     suite.addTest(s)
-
     return suite
 
 if __name__ == '__main__':
